@@ -1,14 +1,19 @@
 import math
+from typing import Type, Union
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
+from torch import Tensor
 
 import torchhd.functional as functional
+from torchhd.base import VSA_Model
+from torchhd.map import MAP
 
 __all__ = [
     "Identity",
     "Random",
     "Level",
+    "Thermometer",
     "Circular",
     "Projection",
     "Sinusoid",
@@ -54,6 +59,9 @@ class Identity(nn.Embedding):
 
         self._fill_padding_idx_with_zero()
 
+    def forward(self, input: Tensor) -> Tensor:
+        return super().forward(input).as_subclass(MAP)
+
 
 class Random(nn.Embedding):
     """Embedding wrapper around :func:`~torchhd.functional.random_hv`.
@@ -94,6 +102,9 @@ class Random(nn.Embedding):
 
         self._fill_padding_idx_with_zero()
 
+    def forward(self, input: Tensor) -> Tensor:
+        return super().forward(input).as_subclass(MAP)
+
 
 class Level(nn.Embedding):
     """Embedding wrapper around :func:`~torchhd.functional.level_hv`.
@@ -158,7 +169,67 @@ class Level(nn.Embedding):
             input, self.low_value, self.high_value, self.num_embeddings
         ).clamp(0, self.num_embeddings - 1)
 
-        return super(Level, self).forward(indices)
+        return super(Level, self).forward(indices).as_subclass(MAP)
+
+
+class Thermometer(nn.Embedding):
+    """Embedding wrapper around :func:`~torchhd.functional.thermometer_hv`.
+
+    Class inherits from `Embedding <https://pytorch.org/docs/stable/generated/torch.nn.Embedding.html>`_ and supports the same keyword arguments.
+
+    Args:
+        num_embeddings (int): the number of hypervectors to generate.
+        embedding_dim (int): the dimensionality of the hypervectors.
+        low (float, optional): The lower bound of the real number range that the levels represent. Default: ``0.0``
+        high (float, optional): The upper bound of the real number range that the levels represent. Default: ``1.0``
+        requires_grad (bool, optional): If autograd should record operations on the returned tensor. Default: ``False``.
+
+    Examples::
+
+        >>> emb = embeddings.Thermometer(11, 10, low=-1, high=2)
+        >>> x = torch.FloatTensor([0.3, 1.9, -0.8])
+        >>> emb(x)
+        tensor([[ 1.,  1.,  1.,  1., -1., -1., -1., -1., -1., -1.],
+                [ 1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.],
+                [ 1., -1., -1., -1., -1., -1., -1., -1., -1., -1.]])
+
+    """
+
+    def __init__(
+        self,
+        num_embeddings,
+        embedding_dim,
+        low=0.0,
+        high=1.0,
+        requires_grad=False,
+        **kwargs
+    ):
+        self.low_value = low
+        self.high_value = high
+
+        super(Thermometer, self).__init__(num_embeddings, embedding_dim, **kwargs)
+        self.weight.requires_grad = requires_grad
+
+    def reset_parameters(self):
+        factory_kwargs = {
+            "device": self.weight.data.device,
+            "dtype": self.weight.data.dtype,
+        }
+
+        self.weight.data.copy_(
+            functional.thermometer_hv(
+                self.num_embeddings, self.embedding_dim, **factory_kwargs
+            )
+        )
+
+        self._fill_padding_idx_with_zero()
+
+    def forward(self, input: torch.Tensor) -> torch.Tensor:
+        indices = functional.value_to_index(
+            input, self.low_value, self.high_value, self.num_embeddings
+        ).clamp(0, self.num_embeddings - 1)
+
+        return super(Thermometer, self).forward(indices).as_subclass(MAP)
 
 
 class Circular(nn.Embedding):
@@ -224,7 +295,7 @@ class Circular(nn.Embedding):
             input, self.low_value, self.high_value, self.num_embeddings
         ).remainder(self.num_embeddings - 1)
 
-        return super(Circular, self).forward(indices)
+        return super(Circular, self).forward(indices).as_subclass(MAP)
 
 
 class Projection(nn.Module):
@@ -280,7 +351,7 @@ class Projection(nn.Module):
         self.weight.data.copy_(F.normalize(self.weight.data))
 
     def forward(self, input: torch.Tensor) -> torch.Tensor:
-        return F.linear(input, self.weight)
+        return F.linear(input, self.weight).as_subclass(MAP)
 
 
 class Sinusoid(nn.Module):
@@ -342,4 +413,5 @@ class Sinusoid(nn.Module):
 
     def forward(self, input: torch.Tensor) -> torch.Tensor:
         projected = F.linear(input, self.weight)
-        return torch.cos(projected + self.bias) * torch.sin(projected)
+        output = torch.cos(projected + self.bias) * torch.sin(projected)
+        return output.as_subclass(MAP)
